parse_link_references

Function parse_link_references 

pub fn parse_link_references(text: &str) -> Vec<Vec<String>>
Parse link references found in Markdown content.

Args: text (str): Markdown content to be parsed.

Returns: list: Tuples or lists with 3 values (target, href, title) for each link reference. If a title is not found or an identifier is empty they will be returned as empty strings.